// https://nuxt.com/docs/api/configuration/nuxt-config
export default defineNuxtConfig({
  ssr: false,
  css: ["~/assets/css/main.css"],
  devtools: { enabled: true },
  app: {
    head: {
      title: "Artific Test Case.",
      link: [
        { rel: "icon", type: "image/png", href: "/favicon.png" },
        {
          rel: "apple-touch-icon",
          sizes: "180x180",
          type: "image/png",
          href: "/apple-touch-icon.png",
        },
        {
          rel: "icon",
          sizes: "32x32",
          type: "image/png",
          href: "/favicon-32x32.png",
        },
        {
          rel: "icon",
          sizes: "192x192",
          type: "image/png",
          href: "/android-chrome-192x192.png",
        },
        {
          rel: "icon",
          sizes: "16x16",
          type: "image/png",
          href: "/favicon-16x16.png",
        },
        { rel: "mask-icon", color: "#287ceb", href: "/safari-pinned-tab.svg" },
        { rel: "manifest", href: "/site.webmanifest" },
      ],
      meta: [
        { name: "description", content: "Een testcase" },
        { name: "msapplication-TileColor", content: "#287ceb" },
        { name: "theme-color", content: "#287ceb" },
      ],
    },
  },
  modules: ["@vueuse/nuxt"],
  imports: {
    dirs: ["stores", "types"],
  },
  postcss: {
    plugins: {
      tailwindcss: {},
      autoprefixer: {},
    },
  },
  runtimeConfig: {
    public: {
      apiBaseUrl: process.env.NUXT_API_BASE_URL || "http://localhost:8008",
      sdlcRootUrl: process.env.NUXT_SDLC_ROOT_URL || "/",
      firebaseConfig: {
        apiKey: process.env.NUXT_FIREBASE_API_KEY,
        authDomain: process.env.NUXT_FIREBASE_AUTH_DOMAIN,
        projectId: process.env.NUXT_FIREBASE_PROJECT_ID,
        databaseURL: process.env.NUXT_FIREBASE_DATABASE_URL,
        storageBucket: process.env.NUXT_FIREBASE_STORAGE_BUCKET,
        messagingSenderId: process.env.NUXT_FIREBASE_MESSAGING_SENDER_ID,
        appId: process.env.NUXT_FIREBASE_APP_ID,
        measurementId: process.env.NUXT_FIREBASE_MEASUREMENT_ID,
      },
    },
  },
});
